@@ -90,51 +90,12 @@ class VariableOsInstallNetInterfaces(NetHelper,ReadonlyVariable):
 class VariableOsInstallNetInterfacesOrig(NetHelper,ReadonlyVariable):
     """
     Net interface devices orig name from udev (enp0s2)
+    Depricated
     """
     type = "list"
 
-    def is_classic_interface_name(self):
-        hashsum = lambda x: hashlib.md5(readFile(x)).digest()
-        chroot_path = self.Get('cl_chroot_path')
-        if isPkgInstalled('sys-fs/eudev', prefix=chroot_path):
-            return True
-        etc_path_join = partial(path.join,
-                                chroot_path, 'etc/udev/rules.d')
-        lib_path_join = partial(path.join,
-                                chroot_path, 'lib/udev/rules.d')
-        udev_files = ('70-persistent-net.rules',
-                      '80-net-name-slot.rules',
-                      '80-net-setup-link.rules')
-        for etc_file, lib_file in  izip(map(etc_path_join,udev_files),
-                                        map(lib_path_join,udev_files)):
-            if path.exists(etc_file) and hashsum(etc_file) != hashsum(lib_file):
-                return True
-        return False
-
     def get(self):
-        if self.is_classic_interface_name():
-            return self.Get('os_install_net_interfaces')
-        def getOrig(x):
-            try:
-                nameParam = \
-                    map(lambda x:x.partition('=')[::2],
-                    filter(lambda x:any(x.startswith(y)
-                                    for y in ("ID_NET_NAME_PATH=",
-                                              "ID_NET_NAME_SLOT=",
-                                              "ID_NET_NAME_ONBOARD=")),
-                    process("udevadm","test-builtin","net_id",
-                                    "/sys/class/net/%s"%x)))
-                if nameParam:
-                    sortOrder = {'ID_NET_NAME_PATH':0,
-                                 'ID_NET_NAME_SLOT':1,
-                                 'ID_NET_NAME_ONBOARD':2}
-                    nameParam = sorted(nameParam,
-                                key=lambda x:sortOrder.get(x[0],-1))
-                    return nameParam[-1][1].strip() or x
-            except Exception as e:
-                return x
-            return x
-        return map(getOrig,self.Get('os_install_net_interfaces'))
+        return self.Get('os_install_net_interfaces')
 
 class VariableOsNetInterfacesInfo(NetHelper,ReadonlyVariable):
     """
